@@ -71,9 +71,9 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_ecr
-import aws_cdk.aws_iam
-import constructs
+import aws_cdk.aws_ecr as _aws_cdk_aws_ecr_ceddda9d
+import aws_cdk.aws_iam as _aws_cdk_aws_iam_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class Destination(
@@ -97,7 +97,7 @@ class Destination(
     @builtins.classmethod
     def ecr(
         cls,
-        repository: aws_cdk.aws_ecr.IRepository,
+        repository: _aws_cdk_aws_ecr_ceddda9d.IRepository,
         *,
         tag: typing.Optional[builtins.str] = None,
     ) -> "Destination":
@@ -107,13 +107,7 @@ class Destination(
         :param tag: Tag of deployed image. Default: - tag of source
         '''
         if __debug__:
-            def stub(
-                repository: aws_cdk.aws_ecr.IRepository,
-                *,
-                tag: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__0c54a04beda47ee3571d27fb1776b4ffa8d1baa651e949586e806ae0d1e71d50)
             check_type(argname="argument repository", value=repository, expected_type=type_hints["repository"])
         options = EcrSourceOptions(tag=tag)
 
@@ -121,7 +115,7 @@ class Destination(
 
     @jsii.member(jsii_name="bind")
     @abc.abstractmethod
-    def bind(self, role: aws_cdk.aws_iam.IGrantable) -> "DestinationConfig":
+    def bind(self, role: _aws_cdk_aws_iam_ceddda9d.IGrantable) -> "DestinationConfig":
         '''Bind grants the CodeBuild role permissions to pull and push to a repository if necessary.
 
         Bind should be invoked by the caller to get the DestinationConfig.
@@ -133,7 +127,7 @@ class Destination(
 
 class _DestinationProxy(Destination):
     @jsii.member(jsii_name="bind")
-    def bind(self, role: aws_cdk.aws_iam.IGrantable) -> "DestinationConfig":
+    def bind(self, role: _aws_cdk_aws_iam_ceddda9d.IGrantable) -> "DestinationConfig":
         '''Bind grants the CodeBuild role permissions to pull and push to a repository if necessary.
 
         Bind should be invoked by the caller to get the DestinationConfig.
@@ -141,9 +135,7 @@ class _DestinationProxy(Destination):
         :param role: -
         '''
         if __debug__:
-            def stub(role: aws_cdk.aws_iam.IGrantable) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__a72c8919b92b60128c0141d7dc0f052b2794fbe84d15e7bc089a1deebded9c1a)
             check_type(argname="argument role", value=role, expected_type=type_hints["role"])
         return typing.cast("DestinationConfig", jsii.invoke(self, "bind", [role]))
 
@@ -165,7 +157,7 @@ class DestinationConfig:
         self,
         *,
         destination_uri: builtins.str,
-        login_config: typing.Union["LoginConfig", typing.Dict[str, typing.Any]],
+        login_config: typing.Union["LoginConfig", typing.Dict[builtins.str, typing.Any]],
         destination_tag: typing.Optional[builtins.str] = None,
     ) -> None:
         '''Destination information.
@@ -177,18 +169,11 @@ class DestinationConfig:
         if isinstance(login_config, dict):
             login_config = LoginConfig(**login_config)
         if __debug__:
-            def stub(
-                *,
-                destination_uri: builtins.str,
-                login_config: typing.Union[LoginConfig, typing.Dict[str, typing.Any]],
-                destination_tag: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__6c4d6944397e455f8103ad368412e09a6c10b74703506a5c7f59780b39d51acf)
             check_type(argname="argument destination_uri", value=destination_uri, expected_type=type_hints["destination_uri"])
             check_type(argname="argument login_config", value=login_config, expected_type=type_hints["login_config"])
             check_type(argname="argument destination_tag", value=destination_tag, expected_type=type_hints["destination_tag"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "destination_uri": destination_uri,
             "login_config": login_config,
         }
@@ -231,7 +216,7 @@ class DestinationConfig:
 
 
 class DockerImageDeployment(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="cdk-docker-image-deployment.DockerImageDeployment",
 ):
@@ -239,7 +224,7 @@ class DockerImageDeployment(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         destination: Destination,
@@ -252,15 +237,7 @@ class DockerImageDeployment(
         :param source: Source of the image to deploy.
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                destination: Destination,
-                source: Source,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__a2105050e0037a99087a0a9f4c72648eac026dc77ac1653449544314b8074152)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = DockerImageDeploymentProps(destination=destination, source=source)
@@ -280,12 +257,10 @@ class DockerImageDeploymentProps:
         :param source: Source of the image to deploy.
         '''
         if __debug__:
-            def stub(*, destination: Destination, source: Source) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__08edffa43996dc151a99914067a04c7d973855ab66ba9e857b3b0a3f8c9e7e80)
             check_type(argname="argument destination", value=destination, expected_type=type_hints["destination"])
             check_type(argname="argument source", value=source, expected_type=type_hints["source"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "destination": destination,
             "source": source,
         }
@@ -328,11 +303,9 @@ class EcrSourceOptions:
         :param tag: Tag of deployed image. Default: - tag of source
         '''
         if __debug__:
-            def stub(*, tag: typing.Optional[builtins.str] = None) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__8bd258127f97145e592aa9e2f8f153fcadf95f957f225e6b5c5c6a17d1f54fba)
             check_type(argname="argument tag", value=tag, expected_type=type_hints["tag"])
-        self._values: typing.Dict[str, typing.Any] = {}
+        self._values: typing.Dict[builtins.str, typing.Any] = {}
         if tag is not None:
             self._values["tag"] = tag
 
@@ -375,16 +348,10 @@ class LoginConfig:
         :param region: Region of ECR repository. Default: - undefined if not an ECR repository
         '''
         if __debug__:
-            def stub(
-                *,
-                login_command: builtins.str,
-                region: typing.Optional[builtins.str] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__9f2f12359ef734edbf3a5098ef6a82f3b30647b3752f1c56209bf3838f81f12b)
             check_type(argname="argument login_command", value=login_command, expected_type=type_hints["login_command"])
             check_type(argname="argument region", value=region, expected_type=type_hints["region"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "login_command": login_command,
         }
         if region is not None:
@@ -445,9 +412,7 @@ class Source(
         :param path: - path to the directory containing your Dockerfile (not a path to a file).
         '''
         if __debug__:
-            def stub(path: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__db65ec22904789f5c5885c02be8a370e36cc22d0ec17e7c61516250420ad62be)
             check_type(argname="argument path", value=path, expected_type=type_hints["path"])
         return typing.cast("Source", jsii.sinvoke(cls, "directory", [path]))
 
@@ -455,9 +420,9 @@ class Source(
     @abc.abstractmethod
     def bind(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         *,
-        handler_role: aws_cdk.aws_iam.IRole,
+        handler_role: _aws_cdk_aws_iam_ceddda9d.IRole,
     ) -> "SourceConfig":
         '''Bind grants the CodeBuild role permissions to pull from a repository if necessary.
 
@@ -473,9 +438,9 @@ class _SourceProxy(Source):
     @jsii.member(jsii_name="bind")
     def bind(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         *,
-        handler_role: aws_cdk.aws_iam.IRole,
+        handler_role: _aws_cdk_aws_iam_ceddda9d.IRole,
     ) -> "SourceConfig":
         '''Bind grants the CodeBuild role permissions to pull from a repository if necessary.
 
@@ -485,13 +450,7 @@ class _SourceProxy(Source):
         :param handler_role: The role for the handler.
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                *,
-                handler_role: aws_cdk.aws_iam.IRole,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__8cca505ce83d3a1ab271e3a2cbb637b501f2fc5ab1cfa0f1499639a44bc900ff)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
         context = SourceContext(handler_role=handler_role)
 
@@ -516,7 +475,7 @@ class SourceConfig:
         *,
         image_tag: builtins.str,
         image_uri: builtins.str,
-        login_config: typing.Union[LoginConfig, typing.Dict[str, typing.Any]],
+        login_config: typing.Union[LoginConfig, typing.Dict[builtins.str, typing.Any]],
     ) -> None:
         '''Source information.
 
@@ -527,18 +486,11 @@ class SourceConfig:
         if isinstance(login_config, dict):
             login_config = LoginConfig(**login_config)
         if __debug__:
-            def stub(
-                *,
-                image_tag: builtins.str,
-                image_uri: builtins.str,
-                login_config: typing.Union[LoginConfig, typing.Dict[str, typing.Any]],
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__d1029c54211a3b9c9b891ec2bf98ac64a4d2016a2c33156e7dc580035a35e7c3)
             check_type(argname="argument image_tag", value=image_tag, expected_type=type_hints["image_tag"])
             check_type(argname="argument image_uri", value=image_uri, expected_type=type_hints["image_uri"])
             check_type(argname="argument login_config", value=login_config, expected_type=type_hints["login_config"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "image_tag": image_tag,
             "image_uri": image_uri,
             "login_config": login_config,
@@ -583,26 +535,24 @@ class SourceConfig:
     name_mapping={"handler_role": "handlerRole"},
 )
 class SourceContext:
-    def __init__(self, *, handler_role: aws_cdk.aws_iam.IRole) -> None:
+    def __init__(self, *, handler_role: _aws_cdk_aws_iam_ceddda9d.IRole) -> None:
         '''Bind context for Source.
 
         :param handler_role: The role for the handler.
         '''
         if __debug__:
-            def stub(*, handler_role: aws_cdk.aws_iam.IRole) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__dbb60b58353b017d9771a1222eb1ebcdb71ddd51b24aa13fa203b9c9447c21e5)
             check_type(argname="argument handler_role", value=handler_role, expected_type=type_hints["handler_role"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "handler_role": handler_role,
         }
 
     @builtins.property
-    def handler_role(self) -> aws_cdk.aws_iam.IRole:
+    def handler_role(self) -> _aws_cdk_aws_iam_ceddda9d.IRole:
         '''The role for the handler.'''
         result = self._values.get("handler_role")
         assert result is not None, "Required property 'handler_role' is missing"
-        return typing.cast(aws_cdk.aws_iam.IRole, result)
+        return typing.cast(_aws_cdk_aws_iam_ceddda9d.IRole, result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -629,3 +579,89 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__0c54a04beda47ee3571d27fb1776b4ffa8d1baa651e949586e806ae0d1e71d50(
+    repository: _aws_cdk_aws_ecr_ceddda9d.IRepository,
+    *,
+    tag: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a72c8919b92b60128c0141d7dc0f052b2794fbe84d15e7bc089a1deebded9c1a(
+    role: _aws_cdk_aws_iam_ceddda9d.IGrantable,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__6c4d6944397e455f8103ad368412e09a6c10b74703506a5c7f59780b39d51acf(
+    *,
+    destination_uri: builtins.str,
+    login_config: typing.Union[LoginConfig, typing.Dict[builtins.str, typing.Any]],
+    destination_tag: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a2105050e0037a99087a0a9f4c72648eac026dc77ac1653449544314b8074152(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    destination: Destination,
+    source: Source,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__08edffa43996dc151a99914067a04c7d973855ab66ba9e857b3b0a3f8c9e7e80(
+    *,
+    destination: Destination,
+    source: Source,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8bd258127f97145e592aa9e2f8f153fcadf95f957f225e6b5c5c6a17d1f54fba(
+    *,
+    tag: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9f2f12359ef734edbf3a5098ef6a82f3b30647b3752f1c56209bf3838f81f12b(
+    *,
+    login_command: builtins.str,
+    region: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__db65ec22904789f5c5885c02be8a370e36cc22d0ec17e7c61516250420ad62be(
+    path: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8cca505ce83d3a1ab271e3a2cbb637b501f2fc5ab1cfa0f1499639a44bc900ff(
+    scope: _constructs_77d1e7e8.Construct,
+    *,
+    handler_role: _aws_cdk_aws_iam_ceddda9d.IRole,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d1029c54211a3b9c9b891ec2bf98ac64a4d2016a2c33156e7dc580035a35e7c3(
+    *,
+    image_tag: builtins.str,
+    image_uri: builtins.str,
+    login_config: typing.Union[LoginConfig, typing.Dict[builtins.str, typing.Any]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__dbb60b58353b017d9771a1222eb1ebcdb71ddd51b24aa13fa203b9c9447c21e5(
+    *,
+    handler_role: _aws_cdk_aws_iam_ceddda9d.IRole,
+) -> None:
+    """Type checking stubs"""
+    pass
